@@ -8,7 +8,6 @@
 '''A simple Twitter client made with pyqt4'''
 
 import httplib2
-import re
 import os
 
 # import sip
@@ -22,6 +21,10 @@ from PySide.QtGui import QMainWindow, QSizePolicy, QSpinBox, QVBoxLayout, \
 from PySide.QtCore import Qt, QUrl, QAbstractListModel, QSettings, QModelIndex, \
     Signal
 
+from theme import DEFAULTTHEME, WHITETHEME, \
+                     COOLWHITETHEME, COOLGRAYTHEME, \
+                     MINITHEME
+
 SUPPORTED_ACCOUNTS = [{
     'name': 'Twitter',
     'consumer_key': 'uhgjkoA2lggG4Rh0ggUeQ',
@@ -48,7 +51,7 @@ try:
 except:
     from cgi import parse_qs
 
-from PySide.QtWebKit import *
+from PySide.QtWebKit import QWebView
 
 
 class OAuthView(QWebView):
@@ -81,6 +84,7 @@ class OAuthView(QWebView):
         return self
 
     def _loadFinished(self):
+        import re
 
         regex = re.compile('.*<div.*oauth_pin.*>(.*)<')
         res = regex.findall(self.page().mainFrame().toHtml())
@@ -91,7 +95,7 @@ class OAuthView(QWebView):
             res = regex.findall(self.page().mainFrame().toHtml())
             if len(res) > 0:
                 self.pin = res[0]
-            
+
         self.loggedIn = self.pin not in (None, '')
 
         if self.loggedIn:
@@ -186,11 +190,6 @@ class KhweeteurPref(QMainWindow):
 
     save = Signal()
 
-    DEFAULTTHEME = u'Default'
-    WHITETHEME = u'White'
-    COOLWHITETHEME = u'CoolWhite'
-    COOLGRAYTHEME = u'CoolGray'
-    MINITHEME = u'MiniDefault'
     THEMES = [DEFAULTTHEME, WHITETHEME, COOLWHITETHEME, COOLGRAYTHEME,
               MINITHEME]
 
@@ -202,8 +201,11 @@ class KhweeteurPref(QMainWindow):
 
         self.settings = QSettings()
 
-        self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
-        self.setAttribute(Qt.WA_Maemo5StackedWindow, True)
+        try:
+            self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
+            self.setAttribute(Qt.WA_Maemo5StackedWindow, True)
+        except:
+            pass
         self.setAttribute(Qt.WA_DeleteOnClose, True)
         self.setWindowTitle('Khweeteur Prefs')
 
@@ -276,18 +278,27 @@ class KhweeteurPref(QMainWindow):
             self.useGPS_value.setCheckState(Qt.CheckState(int(self.settings.value('useGPS'))))
         else:
             self.useGPS_value.setCheckState(Qt.CheckState(2))
-            
+
         if self.settings.contains('useGPSOnDemand'):
             self.useGPSOnDemand_value.setCheckState(Qt.CheckState(int(self.settings.value('useGPSOnDemand'))))
         else:
             self.useGPSOnDemand_value.setCheckState(Qt.CheckState(2))
 
         if self.settings.contains('showInfos'):
-            self.showInfos_value.setCheckState(Qt.CheckState(int(self.settings.value('showInfos'
-                    ))))
+            self.showInfos_value.setCheckState(Qt.CheckState(int(self.settings.value('showInfos'))))
         else:
             self.showInfos_value.setCheckState(Qt.CheckState(0))
 
+        if self.settings.contains('showDMNotifications'):
+            self.showDMNotifications_value.setCheckState(Qt.CheckState(int(self.settings.value('showDMNotifications'))))
+        else:
+            self.showDMNotifications_value.setCheckState(Qt.CheckState(2))
+
+        if self.settings.contains('showMentionNotifications'):
+            self.showMentionNotifications_value.setCheckState(Qt.CheckState(int(self.settings.value('showMentionNotifications'))))
+        else:
+            self.showMentionNotifications_value.setCheckState(Qt.CheckState(2))
+
     def savePrefs(self):
         ''' Save the prefs from the GUI to QSettings'''
 
@@ -313,6 +324,8 @@ class KhweeteurPref(QMainWindow):
         self.settings.setValue('useGPS', self.useGPS_value.checkState())
         self.settings.setValue('useGPSOnDemand', self.useGPSOnDemand_value.checkState())
         self.settings.setValue('showInfos', self.showInfos_value.checkState())
+        self.settings.setValue('showDMNotifications', self.showDMNotifications_value.checkState())
+        self.settings.setValue('showMentionNotifications', self.showMentionNotifications_value.checkState())
         self.settings.setValue('tweetHistory', self.history_value.value())
         self.settings.sync()
         self.save.emit()
@@ -407,8 +420,11 @@ class KhweeteurPref(QMainWindow):
             self.oauth_webview.gotpin.connect(self.do_verify_pin)
             self.oauth_win = QMainWindow(self)
             self.oauth_win.setCentralWidget(self.oauth_webview)
-            self.oauth_win.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
-            self.oauth_win.setAttribute(Qt.WA_Maemo5StackedWindow, True)
+            try:
+                self.oauth_win.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
+                self.oauth_win.setAttribute(Qt.WA_Maemo5StackedWindow, True)
+            except:
+                pass
             self.oauth_win.setWindowTitle('Khweeteur OAuth')
             self.oauth_win.show()
         except httplib2.ServerNotFoundError, err:
@@ -442,7 +458,7 @@ class KhweeteurPref(QMainWindow):
         self.scrollArea = QScrollArea(self)
         self.scrollArea.setWidgetResizable(True)
         self.aWidget = QWidget(self.scrollArea)
-        self.aWidget.setMinimumSize(480, 1000)
+        self.aWidget.setMinimumSize(480, 1200)
         self.aWidget.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Expanding)
         self.scrollArea.setSizePolicy(QSizePolicy.Expanding,
                                       QSizePolicy.Expanding)
@@ -490,12 +506,18 @@ class KhweeteurPref(QMainWindow):
 
         self.useGPS_value = QCheckBox(self.tr('Use GPS Geopositionning'))
         self._umain_layout.addWidget(self.useGPS_value, 13, 1)
-        
+
         self.useGPSOnDemand_value = QCheckBox(self.tr('Use GPS On Demand'))
         self._umain_layout.addWidget(self.useGPSOnDemand_value, 14, 1)
 
         self.showInfos_value = QCheckBox(self.tr('Show errors notifications'))
         self._umain_layout.addWidget(self.showInfos_value, 15, 1)
+        
+        self.showDMNotifications_value = QCheckBox(self.tr('Use DMs notifications'))
+        self._umain_layout.addWidget(self.showDMNotifications_value, 16, 1)
+        
+        self.showMentionNotifications_value = QCheckBox(self.tr('Use Mentions notifications'))
+        self._umain_layout.addWidget(self.showMentionNotifications_value, 17, 1)
 
         self._main_layout.addLayout(self._umain_layout)
 
